@@ -27,16 +27,51 @@
 #include <QString>
 #include <QSoundEffect>
 #include <QTimer>
+#include <QGSettings/QGSettings>
+#include <X11/Xlib.h>
 
 #include "ukuipower.h"
 #include "mainwindow.h"
 
+#ifdef signals
+#undef signals
+#endif
+
+bool playShutdownMusic(UkuiPower &powermanager, int num)
+{
+    bool play_music = true;
+    QGSettings *gs = new QGSettings("org.ukui.session","/org/ukui/desktop/session/");
+    play_music = gs->get("boot-music").toBool();
+    gs->set("win-key-release",false);
+    static int action = num;
+    QTimer *timer = new QTimer();
+    timer->setSingleShot(true);
+    if (play_music) {
+        QSoundEffect *soundplayer = new QSoundEffect();
+        soundplayer->setSource(QUrl("qrc:/shutdown.wav"));
+        soundplayer->play();
+
+        QObject::connect(timer, &QTimer::timeout, [&]()
+        {
+            powermanager.doAction(UkuiPower::Action(action));
+            exit(0);
+        });
+        timer->start(1000);
+    } else {
+        powermanager.doAction(UkuiPower::Action(action));
+        exit(0);
+    }
+    return false;
+}
+
 int main(int argc, char* argv[])
 {
+    QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+    QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+
     QApplication a(argc, argv);
 
     UkuiPower powermanager(&a);
-    QTimer *timer = new QTimer();
     bool flag = true;
 
     QCommandLineParser parser;
@@ -47,71 +82,44 @@ int main(int argc, char* argv[])
     parser.addHelpOption();
     parser.addVersionOption();
 
-    QCommandLineOption logoutOption(QStringLiteral("logout"), QApplication::tr("Logout this computer."));
-    parser.addOption(logoutOption);
-    QCommandLineOption shutdownOption(QStringLiteral("shutdown"), QApplication::tr("Shutdown this computer."));
-    parser.addOption(shutdownOption);
     QCommandLineOption switchuserOption(QStringLiteral("switchuser"), QApplication::tr("Switch the user of this computer."));
     parser.addOption(switchuserOption);
+//    QCommandLineOption hibernateOption(QStringLiteral("hibernate"), QApplication::tr("Hibernate this computer."));
+//    parser.addOption(hibernateOption);
+    QCommandLineOption suspendOption(QStringLiteral("suspend"), QApplication::tr("Suspend this computer."));
+    parser.addOption(suspendOption);
+    QCommandLineOption logoutOption(QStringLiteral("logout"), QApplication::tr("Logout this computer."));
+    parser.addOption(logoutOption);
     QCommandLineOption rebootOption(QStringLiteral("reboot"), QApplication::tr("Restart this computer."));
     parser.addOption(rebootOption);
+    QCommandLineOption shutdownOption(QStringLiteral("shutdown"), QApplication::tr("Shutdown this computer."));
+    parser.addOption(shutdownOption);
 
     parser.process(a);
 
-    if (parser.isSet(logoutOption)) {
-        powermanager.playmusic();
-        QObject::connect(timer,&QTimer::timeout,
-                         [&]()
-        {
-                timer->stop();
-                delete timer;
-                powermanager.doAction(UkuiPower::Action(0));
-                a.exit();
-        });
-        timer->start(1000);
-        flag = false;
-    }
-    if (parser.isSet(shutdownOption)) {
-        powermanager.playmusic();
-        QObject::connect(timer,&QTimer::timeout,
-                         [&]()
-        {
-                timer->stop();
-                delete timer;
-                powermanager.doAction(UkuiPower::Action(4));
-                a.exit();
-        });
-        timer->start(1000);
-        flag = false;
-    }
     if (parser.isSet(switchuserOption)) {
-        powermanager.playmusic();
-        QObject::connect(timer,&QTimer::timeout,
-                         [&]()
-        {
-                timer->stop();
-                delete timer;
-                powermanager.doAction(UkuiPower::Action(1));
-                a.exit();
-        });
-        timer->start(1000);
-        flag = false;
+        flag = playShutdownMusic(powermanager, 0);
+    }
+//    if (parser.isSet(hibernateOption)) {
+//        flag = playShutdownMusic(powermanager, 1);
+//    }
+    if (parser.isSet(suspendOption)) {
+        flag = playShutdownMusic(powermanager, 2);
+    }
+    if (parser.isSet(logoutOption)) {
+        flag = playShutdownMusic(powermanager, 4);
     }
     if (parser.isSet(rebootOption)) {
-        powermanager.playmusic();
-        QObject::connect(timer,&QTimer::timeout,
-                         [&]()
-        {
-                timer->stop();
-                delete timer;
-                powermanager.doAction(UkuiPower::Action(3));
-                a.exit();
-        });
-        timer->start(1000);
-        flag = false;
+        flag = playShutdownMusic(powermanager, 5);
+    }
+    if (parser.isSet(shutdownOption)) {
+        flag = playShutdownMusic(powermanager, 6);
     }
     if (flag) {
-        //加载翻译文件
+        QGSettings *gs = new QGSettings("org.ukui.session","/org/ukui/desktop/session/");
+        gs->set("win-key-release",true);
+
+        // Load ts files
         const QString locale = QLocale::system().name();
         QTranslator translator;
         qDebug() << "local: " << locale;
@@ -122,30 +130,19 @@ int main(int argc, char* argv[])
            qDebug() << "Load translations file failed!";
         }
 
-        MainWindow w ;
+        MainWindow *w = new MainWindow();
 
-        //加载qss文件
+        // Load qss file
         QFile qss(":/powerwin.qss");
         qss.open(QFile::ReadOnly);
         a.setStyleSheet(qss.readAll());
         qss.close();
 
-        w.showFullScreen();
-        QObject::connect(w.timer,&QTimer::timeout,
-                         [&]()
+        w->showFullScreen();
+        QObject::connect(w, &MainWindow::signalTostart, [&]()
         {
-            w.timer->stop();
-            delete w.timer;
-            if(!w.isVisible()){
-                qDebug()<<w.close();
-                powermanager.doAction(UkuiPower::Action(w.defaultnum));
-                a.exit();
-            }else{
-                qDebug()<<"somethings wrong has happened! Window can not hide!";
-                a.exit();
-            }
+            playShutdownMusic(powermanager, w->defaultnum);
         });
-
         return a.exec();
     }
     return a.exec();
