@@ -21,12 +21,19 @@
 #include <QMainWindow>
 #include "powerprovider.h"
 #include <QTimer>
+#include "QProcess"
+#include <QPixmap>
+#include <QHash>
+#include <QGSettings/QGSettings>
+//#include <QAbstractNativeEventFilter>
+
+class XEventMonitor;
 
 QT_BEGIN_NAMESPACE
 namespace Ui { class MainWindow; }
 QT_END_NAMESPACE
 
-class MainWindow : public QMainWindow
+class MainWindow : public QMainWindow//,public QAbstractNativeEventFilter
 {
     Q_OBJECT
 
@@ -34,15 +41,36 @@ public:
     MainWindow(QWidget *parent = nullptr);
     QRect m_screen;
     ~MainWindow();
-    void doevent(QEvent *event, QString test2,int i);
+    void doevent(QString test2,int i);
+    void changePoint(QWidget *widget ,QEvent *event ,int i);
+    //void closeEvent(QCloseEvent *event);
+    //virtual bool nativeEventFilter(const QByteArray &eventType, void *message, long *result) override;
 
     QTimer *timer;
     int defaultnum = 0;
 
 private:
+    bool exitt();
+    QGSettings *gs;
     Ui::MainWindow *ui;
     UkuiPower *m_power;
+    XEventMonitor *xEventMonitor;
     void ResizeEvent();
+    bool flag = false;
+    QWidget *lastWidget;
+    int tableNum;
+    QHash<int , QWidget*> map;
+    void refreshBlur(QWidget *last , QWidget *now);
+    bool isSwitchuserHide = true;
+    bool isHibernateHide = true;
+    QPixmap pix;
+
+Q_SIGNALS:
+    void signalTostart();
+
+private Q_SLOTS:
+    void onGlobalKeyPress(const QString &key);
+    void onGlobalkeyRelease(const QString &key);
 
 protected:
     void paintEvent(QPaintEvent *e);
