@@ -26,6 +26,7 @@
 
 #include <QObject>
 
+
 //class ScreenSaver;
 
 class IdleWatcher : public QObject
@@ -38,10 +39,11 @@ public:
     void reset(int timeout);
 
 private slots:
+    void resumingFromIdle();
     void timeoutReached(int identifier);
     void setup();
 
-signals:
+Q_SIGNALS:
     void StatusChanged(uint status);
 
 private:
