@@ -32,6 +32,7 @@
 #include <QDebug>
 #include <QTimer>
 #include <QGSettings/QGSettings>
+#include <QMediaPlayer>
 /* qt会将glib里的signals成员识别为宏，所以取消该宏
  * 后面如果用到signals时，使用Q_SIGNALS代替即可
  **/
@@ -42,6 +43,26 @@
 #define SESSION_REQUIRED_COMPONENTS "org.ukui.session.required-components"
 #define SESSION_REQUIRED_COMPONENTS_PATH "/org/ukui/desktop/session/required-components/"
 
+void ModuleManager::playBootMusic(){
+    //set default value of whether boot-music is opened
+    bool play_music = true;
+    if (QGSettings::isSchemaInstalled("org.ukui.session")){
+        QGSettings *gset = new QGSettings("org.ukui.session","/org/ukui/desktop/session/",this);
+        play_music = gset->get("boot-music").toBool();
+    }
+    if (play_music) {
+        QMediaPlayer *player = new QMediaPlayer;
+        player->setMedia(QUrl("qrc:/startup.wav"));
+        player->play();
+        QObject::connect(player,&QMediaPlayer::stateChanged,[=](QMediaPlayer::State state) {
+            player->stop();
+            player->deleteLater();
+            //delete player;
+            qDebug() << "play state is " << state;
+        });
+    }
+}
+
 ModuleManager::ModuleManager( QObject* parent)
     : QObject(parent)
 {
@@ -70,13 +91,13 @@ void ModuleManager::constructStartupList()
     QString panel;
     QString file_manager;
     QString wm_notfound;
-    if(QGSettings::isSchemaInstalled(id)) {
+    if (QGSettings::isSchemaInstalled(id)) {
         const QGSettings* gs = new QGSettings(SESSION_REQUIRED_COMPONENTS,SESSION_REQUIRED_COMPONENTS_PATH,this);
         window_manager = gs->get("windowmanager").toString() + ".desktop";
         panel = gs->get("panel").toString() + ".desktop";
         file_manager = gs->get("filemanager").toString() + ".desktop";
         wm_notfound = gs->get("windowmanager").toString();
-    }else{
+    } else {
         //gsetting安装失败，或无法获取，设置默认值
         qDebug() << "从gsettings 中或取值失败，设置默认值";
         window_manager = "ukwm.desktop";
@@ -92,43 +113,60 @@ void ModuleManager::constructStartupList()
     bool wm_found = false;
 
     const auto files = XdgAutoStart::desktopFileList(desktop_paths, false);
-    for (const XdgDesktopFile& file : files)
-    {
-        if (QFileInfo(file.fileName()).fileName() == panel)
-        {
+    for (const XdgDesktopFile& file : files) {
+        if (QFileInfo(file.fileName()).fileName() == panel) {
             mPanel = file;
             panel_found = true;
             qDebug() << "panel has been found";
         }
-        if (QFileInfo(file.fileName()).fileName() == file_manager)
-        {
+        if (QFileInfo(file.fileName()).fileName() == file_manager) {
             mFileManager = file;
             fm_found = true;
             qDebug() << "filemanager has been found";
         }
-        if (QFileInfo(file.fileName()).fileName() == window_manager)
-        {
+        if (QFileInfo(file.fileName()).fileName() == window_manager) {
             mWindowManager = file;
             wm_found = true;
             qDebug() << "windowmanager has been found";
         }
 
-        if(fm_found && panel_found && wm_found)
+        if (fm_found && panel_found && wm_found)
             break;
     }
 
-    //配置文件所给的窗口管理器找不到.desktop文件时，将所给QString设为可执行命令，创建一个desktop文件赋给mWindowManager
-    if(wm_found == false){
-        mWindowManager = XdgDesktopFile(XdgDesktopFile::ApplicationType,"window-manager", wm_notfound);
-        qDebug() << "windowmanager has been created";
+    if (wm_found == false) {
+        QFileInfo check_ukwm("/usr/share/applications/ukwm.desktop");
+        QFileInfo check_ukuikwin("/usr/share/applications/ukui-kwin.desktop");
+        if(check_ukwm.exists()) {
+            window_manager = "ukwm.desktop";
+        }else if(check_ukuikwin.exists()) {
+            window_manager = "ukui-kwin.desktop";
+        }
     }
 
+    for (const XdgDesktopFile& file : files) {
+	if (QFileInfo(file.fileName()).fileName() == window_manager){
+	    mWindowManager = file;
+	    wm_found = true;
+	}
+    }
+
+    //配置文件所给的窗口管理器找不到.desktop文件时，将所给QString设为可执行命令，创建一个desktop文件赋给mWindowManager
+//    if (wm_found == false) {
+//        mWindowManager = XdgDesktopFile(XdgDesktopFile::ApplicationType,"window-manager", wm_notfound);
+//        qDebug() << "windowmanager has been created";
+//    }
+
     QString desktop_phase = "X-UKUI-Autostart-Phase";
     QString desktop_type = "Type";
     //设置excludeHidden为true，判断所有desktop文件的Hidden值，若为true，则将其从自启列表中去掉
     const XdgDesktopFileList all_file_list = XdgAutoStart::desktopFileList(true);
     for (XdgDesktopFileList::const_iterator i = all_file_list.constBegin(); i != all_file_list.constEnd(); ++i)
     {
+        QString filename = QFileInfo(i->fileName()).fileName();
+        if(filename == panel || filename == file_manager || filename == window_manager){
+            continue;
+        }
         const XdgDesktopFile file = *i;
         if (i->contains(desktop_phase)) {
             QStringList s1 =file.value(desktop_phase).toString().split(QLatin1Char(';'));
@@ -169,37 +207,44 @@ void ModuleManager::constructStartupList()
 void ModuleManager::startup()
 {
     qDebug() << "Start Initialization app: ";
-    for (XdgDesktopFileList::const_iterator i = mInitialization.constBegin(); i != mInitialization.constEnd(); ++i){
+    for (XdgDesktopFileList::const_iterator i = mInitialization.constBegin(); i != mInitialization.constEnd(); ++i) {
         startProcess(*i, true);
     }
+    QTimer::singleShot(1000, this, [&]()
+    {
+        qDebug() << "Start window manager: " << mWindowManager.name();
+        startProcess(mWindowManager, true);
 
-    qDebug() << "Start window manager: " << mWindowManager.name();
-    startProcess(mWindowManager, true);
+        QTimer::singleShot(1000, this, [&]()
+        {
+            qDebug() << "Start file manager: " << mFileManager.name();
+            startProcess(mFileManager, true);
 
-    qDebug() << "Start panel: " << mPanel.name();
-    startProcess(mPanel, true);
+            qDebug() << "Start panel: " << mPanel.name();
+            startProcess(mPanel, true);
 
-    qDebug() << "wait for ukui-settings-daemon start-up";
-    timer = new QTimer();
-    connect(timer,SIGNAL(timeout()),this,SLOT(timerUpdate()));
-    timer->start(1000);
+            playBootMusic();
+
+            qDebug() << "wait for ukui-settings-daemon start-up";
+            timer = new QTimer();
+            connect(timer,SIGNAL(timeout()),this,SLOT(timerUpdate()));
+            timer->start(3000);
+        });
+    });
 }
 
 void ModuleManager::timerUpdate(){
     timer->stop();
     delete timer;
 
-    qDebug() << "Start file manager: " << mFileManager.name();
-    startProcess(mFileManager, true);
-
     qDebug() << "Start desktop: ";
-    for (XdgDesktopFileList::const_iterator i = mDesktop.constBegin(); i != mDesktop.constEnd(); ++i){
+    for (XdgDesktopFileList::const_iterator i = mDesktop.constBegin(); i != mDesktop.constEnd(); ++i) {
         startProcess(*i, true);
     }
 
     qDebug() << "Start application: ";
     QFile file("/etc/xdg/autostart/kylin-nm.desktop");
-    for (XdgDesktopFileList::const_iterator i = mApplication.constBegin(); i != mApplication.constEnd(); ++i){
+    for (XdgDesktopFileList::const_iterator i = mApplication.constBegin(); i != mApplication.constEnd(); ++i) {
         qDebug() << i->fileName();
         if(i->fileName()=="/etc/xdg/autostart/nm-applet.desktop" && file.exists()){
             qDebug() << "the kylin-nm exist so the nm-applet will not start";
@@ -220,23 +265,20 @@ void ModuleManager::timerUpdate(){
 void ModuleManager::startProcess(const XdgDesktopFile& file, bool required)
 {
     QStringList args = file.expandExecString();
-    if (args.isEmpty())
-    {
+    if (args.isEmpty()) {
         qWarning() << "Wrong desktop file: " << file.fileName();
         return;
     }
 
     QString name = QFileInfo(file.fileName()).fileName();
-    if (!mNameMap.contains(name))
-    {
+    if (!mNameMap.contains(name)) {
         UkuiModule* proc = new UkuiModule(file, this);
         connect(proc, &UkuiModule::moduleStateChanged, this, &ModuleManager::moduleStateChanged);
         proc->start();
 
         mNameMap[name] = proc;
 
-        if (required || autoRestart(file))
-        {
+        if (required || autoRestart(file)) {
             connect(proc, SIGNAL(finished(int, QProcess::ExitStatus)),
                 this, SLOT(restartModules(int, QProcess::ExitStatus)));
         }
@@ -250,10 +292,8 @@ void ModuleManager::startProcess(const QString& name, bool required)
     desktop_paths << "/usr/share/applications";
 
     const auto files = XdgAutoStart::desktopFileList(desktop_paths, false);
-    for (const XdgDesktopFile& file : files)
-    {
-        if (QFileInfo(file.fileName()).fileName() == desktop_name)
-        {
+    for (const XdgDesktopFile& file : files) {
+        if (QFileInfo(file.fileName()).fileName() == desktop_name) {
             startProcess(file, required);
             return;
         }
@@ -283,7 +323,7 @@ bool ModuleManager::autoRestart(const XdgDesktopFile &file)
 void ModuleManager::restartModules(int /*exitCode*/, QProcess::ExitStatus exitStatus)
 {
     UkuiModule* proc = qobject_cast<UkuiModule*>(sender());
-    if(proc->restartNum > 10){
+    if (proc->restartNum > 10) {
         mNameMap.remove(proc->fileName);
         disconnect(proc, SIGNAL(finished(int, QProcess::ExitStatus)), nullptr, nullptr);
         proc->deleteLater();
@@ -294,22 +334,25 @@ void ModuleManager::restartModules(int /*exitCode*/, QProcess::ExitStatus exitSt
         return;
     }
 
-    if (!proc->isTerminating())
-    {
+    if (!proc->isTerminating()) {
         QString procName = proc->file.name();
-        switch (exitStatus)
-        {
-            case QProcess::NormalExit:
-                qDebug() << "Process" << procName << "(" << proc << ") exited correctly.";
-                break;
-            case QProcess::CrashExit:
-            {
-                qDebug() << "Process" << procName << "(" << proc << ") has to be restarted";
-                proc->start();
-                proc->restartNum++;
-                return;
-//                time_t now = time(NULL);
-            }
+        if(procName == QFileInfo(mWindowManager.name()).fileName()){
+            qDebug() << "Process" << procName << "(" << proc << ") has to be restarted";
+            proc->start();
+            proc->restartNum++;
+            return;
+        }
+        switch (exitStatus) {
+        case QProcess::NormalExit:
+            qDebug() << "Process" << procName << "(" << proc << ") exited correctly.";
+            break;
+        case QProcess::CrashExit:
+            qDebug() << "Process" << procName << "(" << proc << ") has to be restarted";
+            proc->start();
+            proc->restartNum++;
+            return;
+        default:
+            qWarning() << "Unknown exit status: " << procName << "(" << proc << ")";
         }
     }
     mNameMap.remove(proc->fileName);
@@ -319,22 +362,34 @@ void ModuleManager::restartModules(int /*exitCode*/, QProcess::ExitStatus exitSt
 void ModuleManager::logout(bool doExit)
 {
     ModulesMapIterator i(mNameMap);
+    UkuiModule *winman;
     while (i.hasNext()) {
         i.next();
         qDebug() << "Module logout" << i.key();
         UkuiModule *p = i.value();
+        if(p->file.name() == QFileInfo(mWindowManager.name()).fileName()){
+            winman = p;
+            continue;
+        }
         p->terminate();
     }
     i.toFront();
     while (i.hasNext()) {
         i.next();
         UkuiModule *p = i.value();
-        if (p->state() != QProcess::NotRunning && !p->waitForFinished(2000)) {
+        if(p->file.name() == QFileInfo(mWindowManager.name()).fileName()){
+            continue;
+        }
+        if (p->state() != QProcess::NotRunning && !p->waitForFinished(200)) {
             qWarning() << "Module " << qPrintable(i.key()) << " won't termiante .. killing.";
             p->kill();
         }
     }
-    if (doExit)
-        QCoreApplication::exit(0);
+    winman->terminate();
+
+    if (doExit) {
+        //QCoreApplication::exit(0);
+        exit(0);
+    }
 }
 
