@@ -26,93 +26,78 @@
 #include <QDebug>
 #include <QMediaPlayer>
 #include <QDesktopWidget>
+#include "../tools/ukuipower.h"
 
 #define SESSION_DEFAULT_SETTINGS "org.ukui.session"
+#define SESSION_DEFAULT_SETTINGS_PATH "/org/ukui/desktop/session/"
 #define QT5_UKUI_STYLE "org.ukui.style"
+#define PERIPHERALS_MOUSE "org.ukui.peripherals-mouse"
+#define PERIPHERALS_MOUSE_PATH "/org/ukui/desktop/peripherals/mouse/"
+#define MOUSE_KEY "cursor-size"
+
+#define FONT_RENDERING_SCHEMAS "org.ukui.font-rendering"
+#define FONT_REENDERING_PATH "/org/ukui/desktop/font-rendering/"
+#define DPI_KEY "dpi"
+
+QByteArray typeConver(int i){
+    QString str = QString::number(i);
+    QByteArray byte;
+    byte.append(str);
+    return byte;
+}
 
 void SessionApplication::InitialEnvironment()
 {
-    QByteArray gdk_scale_QB;
-    QByteArray qt_scale_factor_QB;
+    UkuiPower *upower = new UkuiPower();
     if(gsettings_usable){
-        int gdk_scale;
-        int qt_scale_factor;
-        QDesktopWidget *desktop = QApplication::desktop();
-        qDebug()<< "Screen-height is"<<desktop->height()<<",Screnn-width is"<<desktop->width();
-        bool Hidpi = gs->get("hidpi").toBool();
-        qDebug()<< "Hidpi is "<<Hidpi;
-        if(Hidpi){
-            gdk_scale = gs->get("gdk-scale").toInt();
-            qt_scale_factor = gs->get("qt-scale-factor").toInt();
-        }else{
-            int i = 1;
-            if(desktop->height() >= 2000)
-                i = 2;
-            gdk_scale = i;
-            qt_scale_factor = i;
-        }
-        //转换类型
-        QString qt_scale_factor_QS = QString::number(qt_scale_factor);
-        qt_scale_factor_QB.append(qt_scale_factor_QS);
-
-        QString gdk_scale_QS = QString::number(gdk_scale);
-        gdk_scale_QB.append(gdk_scale_QS);
-    }else{
-        //设为默认值
-        gdk_scale_QB = "1";
-        qt_scale_factor_QB = "1";
+        if(upower->canAction(UkuiPower::PowerHibernate))
+            gs->set("canhibernate",true);
+	else
+	    gs->set("canhibernate",false);
     }
 
     //检查qt主题是否安装
     const QByteArray qt_style(QT5_UKUI_STYLE);
     QByteArray QT_QPA_PLATFORMTHEME;
-    if(QGSettings::isSchemaInstalled(qt_style)) {
+    if (QGSettings::isSchemaInstalled(qt_style)) {
         QT_QPA_PLATFORMTHEME = "ukui";
-    }else{
+    } else {
         QT_QPA_PLATFORMTHEME = "gtk2";
     }
 
-    qDebug()<< "gdk_scale"<<gdk_scale_QB<<"qt_scale_factor"<<qt_scale_factor_QB;
     qputenv("XDG_CURRENT_DESKTOP","UKUI");
-    qputenv("GDK_SCALE",gdk_scale_QB);
-    qputenv("QT_SCALE_FACTOR",qt_scale_factor_QB);
-    qputenv("QT_AUTO_SCRENN_SET_FACTOR","0");
     qputenv("QT_QPA_PLATFORMTHEME",QT_QPA_PLATFORMTHEME);
 }
 
-void SessionApplication::updatevalue(){
-    if(gsettings_usable){
+void SessionApplication::updateIdleDelay(){
+    if (gsettings_usable) {
         const int time = gs->get("idle-delay").toInt() * 60;
         mIdleWatcher->reset(time);
-    }else
-        return;
+    }
 }
 
 void SessionApplication::registerDBus()
 {
     new SessionDBusAdaptor(modman);
     QDBusConnection dbus = QDBusConnection::sessionBus();
-    if (!dbus.registerService(QStringLiteral("org.gnome.SessionManager")))
-    {
+    if (!dbus.registerService(QStringLiteral("org.gnome.SessionManager"))) {
         qCritical() << "Can't register org.gnome.SessionManager, there is already a session manager!";
     }
-    if (!dbus.registerObject(("/org/gnome/SessionManager"), modman))
-    {
+    if (!dbus.registerObject(("/org/gnome/SessionManager"), modman)) {
         qCritical() << "Can't register object, there is already an object registered at "
                     << "/org/gnome/SessionManager";
     }
 
     int timeout;
-    if(gsettings_usable){
+    if (gsettings_usable) {
         timeout = gs->get("idle-delay").toInt() * 60;
-        connect(gs,&QGSettings::changed,this,&SessionApplication::updatevalue);
-    }else{
+        connect(gs, &QGSettings::changed, this, &SessionApplication::updateIdleDelay);
+    } else {
         timeout = 5 * 60;
     }
     mIdleWatcher = new IdleWatcher(timeout);
     new IdleDBusAdaptor(mIdleWatcher);
-    if (!dbus.registerObject("/org/gnome/SessionManager/Presence", mIdleWatcher))
-    {
+    if (!dbus.registerObject("/org/gnome/SessionManager/Presence", mIdleWatcher)) {
         qCritical() << "Cant' register object, there is already an object registered at "
                     << "org/gnome/SessionManager/Presence";
     }
@@ -122,12 +107,12 @@ SessionApplication::SessionApplication(int& argc, char** argv) :
     QApplication(argc, argv)
 {
     const QByteArray id(SESSION_DEFAULT_SETTINGS);
-    if(QGSettings::isSchemaInstalled(id)) {
+    if (QGSettings::isSchemaInstalled(id)) {
         gsettings_usable = true;
-        gs = new QGSettings("org.ukui.session","/org/ukui/desktop/session/",this);
-    }else{
-        //gsetting安装失败，或无法获取，设置默认值
-        qDebug() << "从gsettings 中或取值失败，设置默认值";
+        gs = new QGSettings(SESSION_DEFAULT_SETTINGS,SESSION_DEFAULT_SETTINGS_PATH,this);
+
+    } else {
+        qWarning() << "Failed to get default value from gsettings, set gsettings_usable to false!";
         gsettings_usable = false;
     }
 
@@ -137,8 +122,6 @@ SessionApplication::SessionApplication(int& argc, char** argv) :
 
     // Wait until the event loop starts
     QTimer::singleShot(0, this, SLOT(startup()));
-
-    playmusic();
 }
 
 SessionApplication::~SessionApplication()
@@ -152,21 +135,8 @@ SessionApplication::~SessionApplication()
 bool SessionApplication::startup()
 {
     QTimer::singleShot(0, this, SLOT(registerDBus()));
-	
+
     modman->startup();
 
     return true;
 }
-
-void SessionApplication::playmusic(){
-    QMediaPlayer *player = new QMediaPlayer;
-    player->setMedia(QUrl("qrc:/startup.wav"));
-    player->play();
-    QObject::connect(player,&QMediaPlayer::stateChanged,[=](QMediaPlayer::State state){
-        player->stop();
-        player->deleteLater();
-        //delete player;
-        qDebug() << "play state is " << state;
-    });
-
-}
