@@ -27,6 +27,7 @@
 /* qt会将glib里的signals成员识别为宏，所以取消该宏
  * 后面如果用到signals时，使用Q_SIGNALS代替即可
  **/
+
 #ifdef signals
 #undef signals
 #endif
@@ -38,14 +39,13 @@ class SessionApplication : public QApplication
 {
     Q_OBJECT
 public:
-    void test();
     SessionApplication(int& argc, char** argv);
     ~SessionApplication();
 
 private Q_SLOTS:
     bool startup();
     void registerDBus();
-    void updatevalue();
+    void updateIdleDelay();
 
 private:
     void InitialEnvironment();
@@ -54,8 +54,8 @@ private:
     QGSettings * gs;
     ModuleManager* modman;
     IdleWatcher* mIdleWatcher;
-    QWidget *widget;
-    void playmusic();
+    //QWidget *widget;
+    void playBootMusic();
 };
 
 #endif // SESSIONAPPLICATION_H
