@@ -64,16 +64,20 @@ public slots:
 
     Q_NOREPLY void reboot()
     {
-        mManager->logout(false);
-        mPower->doAction(UkuiPower::PowerReboot);
-        QCoreApplication::exit(0);
+        if(mPower->canAction(UkuiPower::PowerReboot)){
+            mManager->logout(false);
+            mPower->doAction(UkuiPower::PowerReboot);
+        }
+        //QCoreApplication::exit(0);
     }
 
     Q_NOREPLY void powerOff()
     {
-        mManager->logout(false);
-        mPower->doAction(UkuiPower::PowerShutdown);
-        QCoreApplication::exit(0);
+        if(mPower->canAction(UkuiPower::PowerShutdown)){
+            mManager->logout(false);
+            mPower->doAction(UkuiPower::PowerShutdown);
+        }
+        //QCoreApplication::exit(0);
     }
 
 //    QDBusVariant listModules()
